@@ -20,6 +20,7 @@ from lollypop.art_downloader import ArtDownloader
 from lollypop.tagreader import TagReader
 from lollypop.define import Lp
 from lollypop.objects import Album
+from lollypop.utils import escape
 
 
 class AlbumArt(BaseArt, ArtDownloader, TagReader):
@@ -77,11 +78,11 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
         if album.id is None:
             return None
         try:
+            filename = self._get_album_cache_name(album) + ".jpg"
             paths = [
                 os.path.join(album.path, self._favorite),
                 # Used when having muliple albums in same folder
-                os.path.join(album.path, "{}_{}.jpg".format(album.artist_name,
-                                                            album.name))
+                os.path.join(album.path, filename)
             ]
             for path in paths:
                 if os.path.exists(path):
@@ -205,8 +206,8 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             path_count = Lp().albums.get_path_count(album.path)
             # Many albums with same path, suffix with artist_album name
             if path_count > 1:
-                artpath = os.path.join(album.path, "{}_{}.jpg".format(
-                                       album.artist_name, album.name))
+                filename = self._get_album_cache_name(album) + ".jpg"
+                artpath = os.path.join(album.path, filename)
                 if os.path.exists(os.path.join(album.path, self._favorite)):
                     os.remove(os.path.join(album.path, self._favorite))
             else:
@@ -248,6 +249,10 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             exist = False
             if infos is not None:
                 (exist, sample) = infos.get_tags().get_sample_index('image', 0)
+                # Some file store it in a preview-image tag
+                if not exist:
+                    (exist, sample) = infos.get_tags().get_sample_index(
+                                                            'preview-image', 0)
             if exist:
                 (exist, mapflags) = sample.get_buffer().map(Gst.MapFlags.READ)
             if exist:
@@ -258,8 +263,8 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
                                                                    size,
                                                                    False,
                                                                    None)
-        except:
-            pass
+        except Exception as e:
+            print("AlbumArt::pixbuf_from_tags():", e)
         return pixbuf
 
 #######################
@@ -270,5 +275,6 @@ class AlbumArt(BaseArt, ArtDownloader, TagReader):
             Get a uniq string for album
             @param album as Album
         """
-        path = album.name + "_" + album.artist_name
-        return path[0:240].replace("/", "_")
+        # FIXME special chars
+        name = "_".join(album.artists) + "_" + album.name + "_" + album.year
+        return escape(name)
