@@ -49,6 +49,7 @@ class BaseArt(GObject.GObject):
         cover = GdkPixbuf.Pixbuf.new_from_file(path)
         cover_width = cover.get_width()
         cover_height = cover.get_height()
+        del cover
         if cover_width == cover_height:
             return True
         elif cover_width < cover_height:
@@ -81,7 +82,7 @@ class BaseArt(GObject.GObject):
             code forked Gnome Music, see copyright header
             @param size as int
             @param icon_name as str
-            @return pixbuf as Gdk.Pixbuf
+            @return pixbuf as cairo.Surface
         """
         # First look in cache
         cache_path_jpg = self._get_default_icon_path(size, icon_name)
