@@ -78,10 +78,8 @@ class Container:
             GLib.timeout_add(250, self.update_db)
         else:
             # Something (device manager) is using progress bar
-            progress = None
             if not self._progress.is_visible():
-                progress = self._progress
-            Lp().scanner.update(progress)
+                Lp().scanner.update(self._progress)
 
     def get_genre_id(self):
         """
@@ -112,15 +110,17 @@ class Container:
                             GLib.Variant('ai',
                                          self._list_two.get_selected_ids()))
 
-    def show_playlist_manager(self, object_id, genre_id, is_album):
+    def show_playlist_manager(self, object_id, genre_ids,
+                              artist_ids, is_album):
         """
             Show playlist manager for object_id
             Current view stay present in ViewContainer
             @param object id as int
-            @param genre id as int
+            @param genre ids as [int]
+            @param artist ids as [int]
             @param is_album as bool
         """
-        view = PlaylistsManageView(object_id, genre_id, is_album)
+        view = PlaylistsManageView(object_id, genre_ids, artist_ids, is_album)
         view.populate()
         view.show()
         self._stack.add(view)
@@ -182,13 +182,13 @@ class Container:
                 self._stack.clean_old_views(child)
                 break
 
-    def update_overlays(self):
+    def disable_overlays(self):
         """
-            Update current view
+            Disable overlays
         """
         view = self._stack.get_visible_child()
         if view:
-            view.update_overlays()
+            view.disable_overlays()
 
     def update_view(self):
         """
@@ -205,6 +205,8 @@ class Container:
         values_two = self._list_two.get_selected_ids()
         if not values_two:
             values_one = self._list_one.get_selected_ids()
+            if not values_one:
+                values_one = [Type.POPULARS]
             self._list_one.select_ids([])
             self._list_one.select_ids(values_one)
         if self._list_two.is_visible():
@@ -519,11 +521,11 @@ class Container:
         self._stack.set_visible_child(child)
         self._stack.clean_old_views(child)
 
-    def _update_view_artists(self, artist_ids, genre_ids):
+    def _update_view_artists(self, genre_ids, artist_ids):
         """
             Update current view with artists view
-            @param artist id as int
-            @param genre id as int
+            @param genre ids as [int]
+            @param artist ids as [int]
         """
         def load():
             if genre_ids and genre_ids[0] == Type.ALL:
@@ -543,7 +545,7 @@ class Container:
         self._stack.set_visible_child(view)
         self._stack.clean_old_views(view)
 
-    def _update_view_albums(self, genre_ids, is_compilation=False):
+    def _update_view_albums(self, genre_ids, artist_ids):
         """
             Update current view with albums view
             @param genre ids as [int]
@@ -551,12 +553,12 @@ class Container:
         """
         def load():
             albums = []
+            is_compilation = artist_ids and artist_ids[0] == Type.COMPILATIONS
             if genre_ids and genre_ids[0] == Type.ALL:
-                if is_compilation:
+                if is_compilation or\
+                        Lp().settings.get_value('show-compilations'):
                     albums = Lp().albums.get_compilations()
-                else:
-                    if Lp().settings.get_value('show-compilations'):
-                        albums = Lp().albums.get_compilations()
+                if not is_compilation:
                     albums += Lp().albums.get_ids()
             elif genre_ids and genre_ids[0] == Type.POPULARS:
                 albums = Lp().albums.get_populars()
@@ -564,17 +566,14 @@ class Container:
                 albums = Lp().albums.get_recents()
             elif genre_ids and genre_ids[0] == Type.RANDOMS:
                 albums = Lp().albums.get_randoms()
-            elif is_compilation:
-                albums = Lp().albums.get_compilations(genre_ids)
             else:
-                if Lp().settings.get_value('show-compilations'):
+                if is_compilation or\
+                        Lp().settings.get_value('show-compilations'):
                     albums = Lp().albums.get_compilations(genre_ids)
-                albums += Lp().albums.get_ids([], genre_ids)
+                if not is_compilation:
+                    albums += Lp().albums.get_ids([], genre_ids)
             return albums
 
-        artist_ids = []
-        if is_compilation:
-            artist_ids.append(Type.COMPILATIONS)
         view = AlbumsView(genre_ids, artist_ids)
         loader = Loader(target=load, view=view)
         loader.start()
@@ -600,7 +599,7 @@ class Container:
                 elif playlist_id == Type.RANDOMS:
                     tracks = Lp().tracks.get_randoms()
                 else:
-                    tracks = Lp().playlists.get_tracks_ids(playlist_id)
+                    tracks = Lp().playlists.get_track_ids(playlist_id)
                 for track_id in tracks:
                     if track_id not in track_ids:
                         track_ids.append(track_id)
@@ -612,7 +611,7 @@ class Container:
             loader = Loader(target=load, view=view)
             loader.start()
         else:
-            view = PlaylistsManageView(Type.NONE, None, False)
+            view = PlaylistsManageView(Type.NONE, [], [], False)
             view.populate()
         view.show()
         self._stack.add(view)
@@ -693,25 +692,24 @@ class Container:
                                  Type.RECENTS,
                                  Type.RANDOMS]:
             self._list_two.hide()
-            self._update_view_albums(selected_ids)
+            self._update_view_albums(selected_ids, [])
         elif selected_ids[0] == Type.RADIOS:
             self._list_two.hide()
             self._update_view_radios()
         elif selection_list.is_marked_as_artists():
             self._list_two.hide()
             if selected_ids[0] == Type.ALL:
-                self._update_view_albums(selected_ids)
-            elif selected_ids[0] == Type.COMPILATIONS and\
-                    len(selected_ids) == 1:
-                self._update_view_albums([], True)
+                self._update_view_albums(selected_ids, [])
+            elif selected_ids[0] == Type.COMPILATIONS:
+                self._update_view_albums([], selected_ids)
             else:
-                self._update_view_artists(selected_ids, [])
+                self._update_view_artists([], selected_ids)
         else:
             self._list_two.clear()
             self._setup_list_artists(self._list_two, selected_ids, False)
             self._list_two.show()
             if not self._list_two.will_be_selected():
-                self._update_view_albums(selected_ids, False)
+                self._update_view_albums(selected_ids, [])
 
     def _on_list_populated(self, selection_list):
         """
@@ -732,11 +730,10 @@ class Container:
             return
         if genre_ids[0] == Type.PLAYLISTS:
             self._update_view_playlists(selected_ids)
-        elif selected_ids[0] == Type.COMPILATIONS and\
-                len(selected_ids) == 1:
-            self._update_view_albums(genre_ids, True)
+        elif selected_ids[0] == Type.COMPILATIONS:
+            self._update_view_albums(genre_ids, selected_ids)
         else:
-            self._update_view_artists(selected_ids, genre_ids)
+            self._update_view_artists(genre_ids, selected_ids)
 
     def _on_mount_added(self, vm, mount):
         """
