@@ -47,12 +47,13 @@ class PlaybackController:
         # Can add a \n in markup
         # GTK bug => https://bugzilla.gnome.org/show_bug.cgi?id=749965
         if player.prev_track.id == Type.RADIOS:
-            self._prev_btn.set_tooltip_text(player.prev_track.album_artist)
+            self._prev_btn.set_tooltip_text(
+                                    ", ".join(player.prev_track.album_artists))
         elif player.prev_track.id is not None:
-            prev_artist = escape(player.prev_track.artist)
+            prev_artists = escape(", ".join(player.prev_track.artists))
             prev_title = escape(player.prev_track.title)
             self._prev_btn.set_tooltip_markup("<b>%s</b> - %s" %
-                                              (prev_artist,
+                                              (prev_artists,
                                                prev_title))
         else:
             self._prev_btn.set_tooltip_text("")
@@ -63,12 +64,13 @@ class PlaybackController:
             @param player as Player
         """
         if player.next_track.id == Type.RADIOS:
-            self._next_btn.set_tooltip_text(player.next_track.album_artist)
+            self._next_btn.set_tooltip_text(
+                                    ", ".join(player.next_track.album_artists))
         elif player.next_track.id is not None:
-            next_artist = escape(player.next_track.artist)
+            next_artists = escape(", ".join(player.next_track.artists))
             next_title = escape(player.next_track.title)
             self._next_btn.set_tooltip_markup("<b>%s</b> - %s" %
-                                              (next_artist,
+                                              (next_artists,
                                                next_title))
         else:
             self._prev_btn.set_tooltip_text("")
@@ -141,6 +143,7 @@ class ProgressController:
             Update scale on current changed
             @param player as Player
         """
+        self._progress.clear_marks()
         if player.current_track.id != Type.RADIOS:
             self._progress.set_sensitive(player.current_track.id is not None)
         self._progress.set_value(0.0)
@@ -161,7 +164,6 @@ class ProgressController:
             @param player as Player
         """
         if player.is_playing():
-            self._progress.set_show_fill_level(False)
             if player.current_track.id == Type.RADIOS and\
                     self._timeout_id is not None:
                 GLib.source_remove(self._timeout_id)
@@ -171,7 +173,6 @@ class ProgressController:
                 self._timeout_id = GLib.timeout_add(1000,
                                                     self._update_position)
         else:
-            self._progress.set_show_fill_level(True)
             self._update_position()
             if self._timeout_id is not None:
                 GLib.source_remove(self._timeout_id)
@@ -187,7 +188,7 @@ class ProgressController:
         """
         if not self._seeking and Lp().player.current_track.id != Type.RADIOS:
             if value is None and Lp().player.get_status() != Gst.State.PAUSED:
-                value = Lp().player.get_position_in_track()/1000000
+                value = Lp().player.position/1000000
             if value is not None:
                 self._progress.set_value(value)
                 self._timelabel.set_text(seconds_to_string(value/60))
@@ -221,7 +222,7 @@ class ProgressController:
         """
         (smooth, x, y) = event.get_scroll_deltas()
         if smooth and Lp().player.is_playing():
-            position = Lp().player.get_position_in_track()
+            position = Lp().player.position
             if y > 0:
                 seek = position/1000000/60-5
             else:
@@ -243,6 +244,7 @@ class InfosController:
         """
             Init controller
         """
+        self._infobox = None
         self._artsize = artsize
 
     def on_current_changed(self, player):
@@ -252,12 +254,18 @@ class InfosController:
         """
         art = None
 
-        self._artist_label.set_text(player.current_track.artist)
+        if player.current_track.id is None:
+            if self._infobox is not None:
+                self._infobox.hide()
+            self._cover.hide()
+            return
+
+        self._artist_label.set_text(", ".join(player.current_track.artists))
         self._title_label.set_text(player.current_track.title)
 
         if player.current_track.id == Type.RADIOS:
             art = Lp().art.get_radio_artwork(
-                                   player.current_track.artist,
+                                   ", ".join(player.current_track.artists),
                                    self._artsize*self.get_scale_factor())
         elif player.current_track.id == Type.EXTERNALS:
             art = Lp().art.get_album_artwork2(
@@ -271,6 +279,15 @@ class InfosController:
             self._cover.set_from_surface(art)
             del art
             self._cover.set_tooltip_text(player.current_track.album.name)
-            self._cover_frame.show()
+            self._cover.show()
         else:
-            self._cover_frame.hide()
+            self._cover.hide()
+        if self._infobox is not None:
+            self._infobox.show()
+
+    @property
+    def artsize(self):
+        """
+            Art size as int
+        """
+        return self._artsize
