@@ -17,6 +17,7 @@ from gi.repository import GLib
 from lollypop.define import Lp
 from lollypop.database_upgrade import DatabaseUpgrade
 from lollypop.sqlcursor import SqlCursor
+from lollypop.localized import LocalizedCollation
 
 
 class Database:
@@ -33,7 +34,6 @@ class Database:
     # this make VACUUM not destroy rowids...
     create_albums = '''CREATE TABLE albums (id INTEGER PRIMARY KEY,
                         name TEXT NOT NULL,
-                        artist_id INT NOT NULL,
                         no_album_artist BOOLEAN NOT NULL,
                         year INT,
                         path TEXT NOT NULL,
@@ -44,6 +44,9 @@ class Database:
                                               sortname TEXT NOT NULL)'''
     create_genres = '''CREATE TABLE genres (id INTEGER PRIMARY KEY,
                                             name TEXT NOT NULL)'''
+    create_album_artists = '''CREATE TABLE album_artists (
+                                                album_id INT NOT NULL,
+                                                artist_id INT NOT NULL)'''
     create_album_genres = '''CREATE TABLE album_genres (
                                                 album_id INT NOT NULL,
                                                 genre_id INT NOT NULL)'''
@@ -69,10 +72,10 @@ class Database:
         """
             Create database tables or manage update if needed
         """
+        db_version = Lp().settings.get_value('db-version').get_int32()
+        upgrade = DatabaseUpgrade(db_version, self)
         if os.path.exists(self.DB_PATH):
             with SqlCursor(self) as sql:
-                db_version = Lp().settings.get_value('db-version').get_int32()
-                upgrade = DatabaseUpgrade(db_version, self)
                 upgrade.do_db_upgrade()
                 Lp().settings.set_value('db-version',
                                         GLib.Variant('i', upgrade.count()))
@@ -86,18 +89,23 @@ class Database:
                     sql.execute(self.create_artists)
                     sql.execute(self.create_genres)
                     sql.execute(self.create_album_genres)
+                    sql.execute(self.create_album_artists)
                     sql.execute(self.create_tracks)
                     sql.execute(self.create_track_artists)
                     sql.execute(self.create_track_genres)
                     sql.commit()
-            except:
-                print("Database::__init__(): %s" % self.LOCAL_PATH)
+                    Lp().settings.set_value('db-version',
+                                            GLib.Variant('i', upgrade.count()))
+            except Exception as e:
+                print("Database::__init__(): %s" % e)
 
     def get_cursor(self):
         """
             Return a new sqlite cursor
         """
         try:
-            return sqlite3.connect(self.DB_PATH, 600.0)
+            c = sqlite3.connect(self.DB_PATH, 600.0)
+            c.create_collation('LOCALIZED', LocalizedCollation())
+            return c
         except:
             exit(-1)
