@@ -15,7 +15,7 @@ from gettext import gettext as _
 import itertools
 
 from lollypop.sqlcursor import SqlCursor
-from lollypop.define import Lp, Type
+from lollypop.define import Lp
 
 
 class TracksDatabase:
@@ -109,7 +109,8 @@ class TracksDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT rowid\
-                                  FROM tracks WHERE name=? COLLATE NOCASE",
+                                  FROM tracks WHERE name=?\
+                                  COLLATE NOCASE COLLATE LOCALIZED",
                                  (name,))
             return list(itertools.chain(*result))
 
@@ -238,25 +239,18 @@ class TracksDatabase:
                                   WHERE track_id=?", (track_id,))
             return list(itertools.chain(*result))
 
-    def get_artist_names(self, track_id):
+    def get_artists(self, track_id):
         """
             Get artist names
             @param track id as int
-            @return Genre name as str "artist1, artist2, ..."
+            @return artists as [str]
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT name FROM artists, track_artists\
                                   WHERE track_artists.track_id=?\
                                   AND track_artists.artist_id=artists.rowid",
                                  (track_id,))
-            artists = [row[0] for row in result]
-            album_id = self.get_album_id(track_id)
-            artist_id = Lp().albums.get_artist_id(album_id)
-            if artist_id != Type.COMPILATIONS:
-                artist_name = Lp().albums.get_artist_name(album_id)
-                if artist_name not in artists:
-                    artists.insert(0, artist_name)
-            return ", ".join(artists)
+            return list(itertools.chain(*result))
 
     def get_genre_ids(self, track_id):
         """
@@ -269,19 +263,18 @@ class TracksDatabase:
                                   WHERE track_id=?", (track_id,))
             return list(itertools.chain(*result))
 
-    def get_genre_names(self, track_id):
+    def get_genres(self, track_id):
         """
-            Get genre names
+            Get genres
             @param track id as int
-            @return Genre name as str "genre1, genre2..."
+            @return [str]
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT name FROM genres, track_genres\
                                   WHERE track_genres.track_id=?\
                                   AND track_genres.genre_id=genres.rowid",
                                  (track_id,))
-            genres = [row[0] for row in result]
-            return ", ".join(genres)
+            return list(itertools.chain(*result))
 
     def get_mtimes(self):
         """
@@ -314,23 +307,6 @@ class TracksDatabase:
                 return v
             return (None, None, None, None)
 
-    def get_album_artist_id(self, track_id):
-        """
-            Get album_artist id for track id
-            @param Track id as int
-            @return Performer id as int
-        """
-        with SqlCursor(Lp().db) as sql:
-            result = sql.execute("SELECT albums.artist_id from albums,tracks\
-                                  WHERE tracks.rowid=?\
-                                  AND tracks.album_id ==\
-                                  albums.rowid", (track_id,))
-            v = result.fetchone()
-
-            if v is not None:
-                return v[0]
-            return Type.COMPILATIONS
-
     def get_paths(self):
         """
             Get all tracks filepath
@@ -402,12 +378,16 @@ class TracksDatabase:
         """
         with SqlCursor(Lp().db) as sql:
             result = sql.execute("SELECT tracks.rowid, tracks.name\
-                                  FROM tracks, track_artists, albums\
-                                  WHERE albums.rowid == tracks.album_id\
-                                  AND track_artists.artist_id=?\
-                                  AND track_artists.track_id=tracks.rowid\
-                                  AND albums.artist_id != ?", (artist_id,
-                                                               artist_id))
+                                 FROM tracks, track_artists, album_artists\
+                                 WHERE album_artists.album_id=tracks.album_id\
+                                 AND track_artists.artist_id=?\
+                                 AND track_artists.track_id=tracks.rowid\
+                                 AND NOT EXISTS (\
+                                  SELECT artist_id\
+                                  FROM album_artists\
+                                  WHERE artist_id=track_artists.artist_id\
+                                  AND album_id=tracks.album_id)",
+                                 (artist_id,))
             return list(result)
 
     def get_populars(self):
@@ -614,12 +594,13 @@ class TracksDatabase:
         """
         track_ids = self.get_ids_for_name(title)
         for track_id in track_ids:
-            album_artist = self.get_album_artist_id(track_id)
-            album_artist_name = Lp().artists.get_name(album_artist)
-            if album_artist_name == artist:
-                return track_id
-            artist_name = Lp().tracks.get_artist_names(track_id)
-            if artist_name == artist:
+            album_id = Lp().tracks.get_album_id(track_id)
+            artist_ids = set(Lp().albums.get_artist_ids(album_id)) &\
+                set(Lp().tracks.get_artist_ids(track_id))
+            for artist_id in artist_ids:
+                if artist == Lp().artists.get_name(artist_id):
+                    return track_id
+            if ", ".join(Lp().tracks.get_artists(track_id)) == artist:
                 return track_id
         return None
 
