@@ -15,6 +15,8 @@
 
 from gi.repository import Gio
 
+from os import path
+
 try:
     from gi.repository import Secret
 
@@ -29,6 +31,7 @@ except:
     SecretSchema = None
     SecretAttributes = None
 
+DataPath = path.expanduser("~") + "/.local/share/lollypop"
 
 Lp = Gio.Application.get_default
 
@@ -47,11 +50,16 @@ class SelectionMode:
     LIMITED = 1
 
 
+class OpenLink:
+    NONE = 0
+    OPEN = 1
+    NEW = 2
+
+
 # Represent playback context
 class PlayContext:
     genre_ids = {}
-    next_track = None  # Needed to return from queue
-    prev_track = None  # Needed to return from queue
+    artist_ids = {}
     next = NextContext.NONE
 
 
