@@ -14,6 +14,7 @@ from gi.repository import Gtk, Gdk, GLib
 
 from datetime import datetime
 
+from lollypop.inhibitor import Inhibitor
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.pop_next import NextPopover
 from lollypop.controllers import InfosController, PlaybackController
@@ -33,6 +34,7 @@ class FullScreen(Gtk.Window, InfosController,
             @param parent as Gtk.window
         """
         Gtk.Window.__init__(self)
+        self.set_title("Lollypop")
         PlaybackController.__init__(self)
         ProgressController.__init__(self)
         self.set_application(app)
@@ -42,6 +44,8 @@ class FullScreen(Gtk.Window, InfosController,
         self._signal1_id = None
         self._signal2_id = None
         self.set_decorated(False)
+        self._parent = parent
+
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/FullScreen.ui')
         builder.connect_signals(self)
@@ -67,7 +71,6 @@ class FullScreen(Gtk.Window, InfosController,
         close_btn = builder.get_object('close_btn')
         close_btn.connect('clicked', self._destroy)
         self._cover = builder.get_object('cover')
-        self._cover_frame = builder.get_object('frame')
         self._title_label = builder.get_object('title')
         self._artist_label = builder.get_object('artist')
         self._album_label = builder.get_object('album')
@@ -96,6 +99,8 @@ class FullScreen(Gtk.Window, InfosController,
         if self._timeout1 is None:
             self._timeout1 = GLib.timeout_add(1000, self._update_position)
         Gtk.Window.do_show(self)
+        self._parent.set_skip_pager_hint(True)
+        self._parent.set_skip_taskbar_hint(True)
         now = datetime.now()
         self._datetime.set_label(now.strftime('%a %d %b, %X')[:-3])
         if self._timeout2 is None:
@@ -104,16 +109,20 @@ class FullScreen(Gtk.Window, InfosController,
                 GLib.timeout_add((60-second)*1000, self._update_datetime)
             else:
                 self._timeout2 = GLib.timeout_add(60000, self._update_datetime)
-        self._update_position()
+        self._update_position(Lp().player.position/1000000)
         self.fullscreen()
         self._next_popover.set_relative_to(self._album_label)
         if Lp().player.next_track.id != Type.RADIOS:
             self._next_popover.show()
+        # Disable idle
+        Lp().inhibitor.inhibit(Inhibitor.IDLE)
 
     def do_hide(self):
         """
             Remove signals and unset color
         """
+        self._parent.set_skip_pager_hint(False)
+        self._parent.set_skip_taskbar_hint(False)
         Gtk.Window.do_hide(self)
         if self._signal1_id is not None:
             Lp().player.disconnect(self._signal1_id)
@@ -128,6 +137,8 @@ class FullScreen(Gtk.Window, InfosController,
             GLib.source_remove(self._timeout2)
         self._next_popover.set_relative_to(None)
         self._next_popover.hide()
+        # Enable idle
+        Lp().inhibitor.uninhibit(Inhibitor.IDLE)
 
     def on_current_changed(self, player):
         """
@@ -143,7 +154,7 @@ class FullScreen(Gtk.Window, InfosController,
             self._album_label.set_text(album_name)
         # Do not show next popover non internal tracks as
         # tags will be readed on the fly
-        if player.next_track.id >= 0:
+        if player.next_track.id is not None and player.next_track.id >= 0:
             self._next_popover.update()
             self._next_popover.show()
         else:
