@@ -12,8 +12,7 @@
 
 import gi
 gi.require_version('Secret', '1')
-gi.require_version('Goa', '1.0')
-from gi.repository import GLib, Gio, Goa
+from gi.repository import GLib, Gio
 
 from gettext import gettext as _
 
@@ -24,6 +23,12 @@ except Exception as e:
     print(_("Last.fm authentication disabled"))
     Secret = None
 
+try:
+    gi.require_version('Goa', '1.0')
+    from gi.repository import Goa
+except:
+    pass
+
 from pylast import LastFMNetwork, md5, BadAuthenticationError
 from gettext import gettext as _
 from locale import getdefaultlocale
@@ -229,7 +234,8 @@ class LastFM(LastFMNetwork):
                 if proxy.get_account().props.provider_name == "Last.fm":
                     return proxy.get_oauth2_based()
         except:
-            return None
+            pass
+        return None
 
     def _check_for_proxy(self):
         """
