@@ -230,12 +230,16 @@ class Track(Base):
         """
         name = escape(self.name)
         artists = []
+        album_artist_ids = self.album.artist_ids
         # Show all artists for compilations
-        if self.album.artist_ids[0] == Type.COMPILATIONS:
+        if album_artist_ids[0] == Type.COMPILATIONS:
             artists = self.artists
         # Show only non album artist for albums (and only if one)
-        elif len(self.artists) > 1:
-            artists = [self.artists[1]] + ["..."]
+        elif not Lp().settings.get_value('hide-artists') and\
+                len(self.artists) > 1:
+            for artist in self.artists:
+                if artist not in self.album_artists:
+                    artists.append(artist)
         if artists:
             name = "<b>%s</b> - %s" % (escape(", ".join(artists)), name)
         return name
