@@ -25,7 +25,7 @@ class NextPopover(Gtk.Popover):
             Init popover
         """
         Gtk.Popover.__init__(self)
-        self._should_be_shown = True
+        self._inhibited = False
         self.set_position(Gtk.PositionType.BOTTOM)
         self.connect('map', self._on_map)
         self.connect('unmap', self._on_unmap)
@@ -44,7 +44,7 @@ class NextPopover(Gtk.Popover):
         """
             Update widget with next track
         """
-        self._artist_label.set_text(Lp().player.next_track.artist)
+        self._artist_label.set_text(", ".join(Lp().player.next_track.artists))
         self._title_label.set_text(Lp().player.next_track.title)
         art = Lp().art.get_album_artwork(
                                Lp().player.next_track.album,
@@ -66,12 +66,26 @@ class NextPopover(Gtk.Popover):
         """
             Return True if widget should be shown, not already closed by user
         """
-        return self._should_be_shown and (
+        return not self._inhibited and (
                 Lp().player.is_party() or
                 Lp().settings.get_enum('shuffle') == Shuffle.TRACKS) and\
             Lp().player.next_track.id is not None and\
             Lp().player.next_track.id >= 0
 
+    def inhibit(self, i):
+        """
+            Inhibit popover
+            @param i as bool
+        """
+        self._inhibited = i
+
+    @property
+    def inhibited(self):
+        """
+            Inhibited as bool
+        """
+        return self._inhibited
+
 #######################
 # PRIVATE             #
 #######################
@@ -80,7 +94,7 @@ class NextPopover(Gtk.Popover):
             Connect signal
             @param widget as Gtk.Widget
         """
-        self._should_be_shown = True
+        self._inhibited = False
         self._signal_id = Lp().player.connect('queue-changed', self.update)
 
     def _on_unmap(self, widget):
@@ -114,7 +128,7 @@ class NextPopover(Gtk.Popover):
             @param widget as Gtk.Widget
             @param event as Gdk.Event
         """
-        self._should_be_shown = False
+        self._inhibited = True
         self.hide()
 
     def _on_skip_btn_clicked(self, btn):
