@@ -14,6 +14,7 @@ from gi.repository import Gtk, Gdk, GLib, GObject, Pango
 
 from cgi import escape
 from gettext import gettext as _
+from locale import strcoll
 
 from lollypop.define import Type, Lp, SelectionMode
 
@@ -350,7 +351,7 @@ class SelectionList(Gtk.ScrolledWindow):
             else:
                 a = model.get_value(itera, 1)
                 b = model.get_value(iterb, 1)
-            return a.lower() > b.lower()
+            return strcoll(a, b)
 
     def _row_separator_func(self, model, iterator):
         """
@@ -478,7 +479,12 @@ class SelectionList(Gtk.ScrolledWindow):
         if row_iter is None or self._model.get_value(row_iter, 0) < 0:
             return
 
-        text = self._model.get_value(row_iter, 1)
+        # We need to get artist sortname
+        if self._is_artists:
+            rowid = self._model.get_value(row_iter, 0)
+            text = Lp().artists.get_sortname(rowid)
+        else:
+            text = self._model.get_value(row_iter, 1)
         if text:
             self._popover.set_text("  %s  " % text[0].upper())
             self._popover.set_relative_to(self)
