@@ -18,7 +18,7 @@ import os
 
 from gettext import gettext as _
 
-from lollypop.define import Lp, Type
+from lollypop.define import Lp
 from lollypop.utils import format_artist_name
 
 
@@ -31,7 +31,6 @@ class TagReader:
         """
             Init tag reader
         """
-        self._index = 0
         self.init_discover()
 
     def init_discover(self):
@@ -73,7 +72,7 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return os.path.basename(filepath)
-        (exists, title) = tags.get_string_index('title', self._index)
+        (exists, title) = tags.get_string_index('title', 0)
         if not exists:
             title = os.path.basename(filepath)
         return title
@@ -86,23 +85,60 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return _("Unknown")
-        (exists, artists) = tags.get_string_index('artist', self._index)
-        if not exists:
-            artists = ""
-        return artists
+        artists = []
+        for i in range(tags.get_tag_size('artist')):
+            (exists, read) = tags.get_string_index('artist', i)
+            if exists:
+                artists.append(read)
+        return "; ".join(artists)
 
-    def get_artist_sortname(self, tags):
+    def get_composers(self, tags):
+        """
+            Return composers for tags
+            @param tags as Gst.TagList
+            @return string like "composer1;composer2;..."
+        """
+        if tags is None:
+            return _("Unknown")
+        composers = []
+        for i in range(tags.get_tag_size('composer')):
+            (exists, read) = tags.get_string_index('composer', i)
+            if exists:
+                composers.append(read)
+        return "; ".join(composers)
+
+    def get_performers(self, tags):
+        """
+            Return performers for tags
+            @param tags as Gst.TagList
+            @return string like "performer1;performer2;..."
+        """
+        if tags is None:
+            return _("Unknown")
+        performers = []
+        for i in range(tags.get_tag_size('performer')):
+            (exists, read) = tags.get_string_index('performer', i)
+            if exists:
+                performers.append(read)
+        return "; ".join(performers)
+
+    def get_artist_sortnames(self, tags):
         """
             Return artist sort name
             @param tags as Gst.TagList
-            @return artist sort name as string
+            @return artist sort names as string;string
         """
-        if tags is not None:
-            (exists, sortname) = tags.get_string_index('artist-sortname',
-                                                       self._index)
-        if not exists:
-            sortname = ""
-        return sortname
+        if tags is None:
+            return ""
+        sortnames = []
+        for i in range(tags.get_tag_size('album-artist-sortname')):
+            (exists, read) = tags.get_string_index('album-artist-sortname', i)
+            if exists:
+                sortnames.append(read)
+        if not sortnames:
+            for i in range(tags.get_tag_size('artist-sortname')):
+                (exists, read) = tags.get_string_index('artist-sortname', i)
+        return "; ".join(sortnames)
 
     def get_album_artist(self, tags):
         """
@@ -112,10 +148,12 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return _("Unknown")
-        (exists, artist) = tags.get_string_index('album-artist', self._index)
-        if not exists:
-            artist = ""
-        return artist
+        artists = []
+        for i in range(tags.get_tag_size('album-artist')):
+            (exists, read) = tags.get_string_index('album-artist', i)
+            if exists:
+                artists.append(read)
+        return "; ".join(artists)
 
     def get_album_name(self, tags):
         """
@@ -125,7 +163,7 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return _("Unknown")
-        (exists, album_name) = tags.get_string_index('album', self._index)
+        (exists, album_name) = tags.get_string_index('album', 0)
         if not exists:
             album_name = _("Unknown")
         return album_name
@@ -138,10 +176,12 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return _("Unknown")
-        (exists, genres) = tags.get_string_index('genre', self._index)
-        if not exists:
-            genres = _("Unknown")
-        return genres
+        genres = []
+        for i in range(tags.get_tag_size('genre')):
+            (exists, read) = tags.get_string_index('genre', 0)
+            if exists:
+                genres.append(read)
+        return "; ".join(genres)
 
     def get_discnumber(self, tags):
         """
@@ -151,8 +191,7 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return 0
-        (exists, discnumber) = tags.get_uint_index('album-disc-number',
-                                                   self._index)
+        (exists, discnumber) = tags.get_uint_index('album-disc-number', 0)
         if not exists:
             discnumber = 0
         return discnumber
@@ -165,8 +204,7 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return 0
-        (exists, tracknumber) = tags.get_uint_index('track-number',
-                                                    self._index)
+        (exists, tracknumber) = tags.get_uint_index('track-number', 0)
         if not exists:
             tracknumber = 0
         return tracknumber
@@ -179,60 +217,71 @@ class ScannerTagReader(TagReader):
         """
         if tags is None:
             return None
-        (exists, date) = tags.get_date_index('date', self._index)
+        (exists, date) = tags.get_date_index('date', 0)
         if not exists:
-            (exists, date) = tags.get_date_time_index('datetime',
-                                                      self._index)
+            (exists, date) = tags.get_date_time_index('datetime', 0)
         if exists:
             year = date.get_year()
         else:
             year = None
         return year
 
-    def add_artists(self, artists, album_artist, sortname):
+    def add_artists(self, artists, album_artists, sortnames):
         """
             Add artists to db
             @param artists as [string]
-            @param album artist as string
-            @param sortname as string
+            @param album artists as [string]
+            @param sortnames as [string]
             @commit needed
             @param return ([artist ids as int], [new artist ids as int])
         """
         new_artist_ids = []
-        # Get all artist ids
         artist_ids = []
+        sortsplit = sortnames.split(';')
+        sortlen = len(sortsplit)
+        i = 0
         for artist in artists.split(';'):
-            # Get artist id, add it if missing
-            artist_id = Lp().artists.get_id(artist)
-            if sortname == "":
-                sortname = format_artist_name(artist)
-            if artist_id is None:
-                artist_id = Lp().artists.add(artist, sortname)
-                if artist == album_artist:
-                    new_artist_ids.append(artist_id)
-            else:
-                Lp().artists.set_sortname(artist_id, sortname)
-            artist_ids.append(artist_id)
+            artist = artist.strip()
+            if artist != '':
+                # Get artist id, add it if missing
+                artist_id = Lp().artists.get_id(artist)
+                if i >= sortlen or sortsplit[i] == "":
+                    sortname = format_artist_name(artist)
+                else:
+                    sortname = sortsplit[i].strip()
+                if artist_id is None:
+                    artist_id = Lp().artists.add(artist, sortname)
+                    if artist in album_artists:
+                        new_artist_ids.append(artist_id)
+                else:
+                    Lp().artists.set_sortname(artist_id, sortname)
+                i += 1
+                artist_ids.append(artist_id)
         return (artist_ids, new_artist_ids)
 
-    def add_album_artist(self, album_artist):
+    def add_album_artists(self, artists):
         """
             Add album artist to db
-            @param album_artist as string
+            @param artists as [string]
             @param return ([album artist ids as int], [new as bool])
             @commit needed
         """
-        album_artist_id = None
-        new = False
-        if album_artist:
-            # Get album artist id, add it if missing
-            album_artist_id = Lp().artists.get_id(album_artist)
-            if album_artist_id is None:
-                album_artist_id = Lp().artists.add(album_artist,
-                                                   format_artist_name(
-                                                                 album_artist))
-                new = True
-        return (album_artist_id, new)
+        artist_ids = []
+        new_artist_ids = []
+        for artist in artists.split(';'):
+            artist = artist.strip()
+            if artist != '':
+                # Get album artist id, add it if missing
+                artist_id = Lp().artists.get_id(artist)
+                if artist_id is None:
+                    album_artist_id = Lp().artists.add(artist,
+                                                       format_artist_name(
+                                                                       artist))
+                    artist_ids.append(album_artist_id)
+                    new_artist_ids.append(album_artist_id)
+                else:
+                    artist_ids.append(artist_id)
+        return (artist_ids, new_artist_ids)
 
     def add_genres(self, genres, album_id):
         """
@@ -245,24 +294,22 @@ class ScannerTagReader(TagReader):
         genre_ids = []
         new_genre_ids = []
         for genre in genres.split(';'):
-            # Get genre id, add genre if missing
-            genre_id = Lp().genres.get_id(genre)
-            if genre_id is None:
-                genre_id = Lp().genres.add(genre)
-                new_genre_ids.append(genre_id)
-            genre_ids.append(genre_id)
-
-        for genre_id in genre_ids:
-            Lp().albums.add_genre(album_id, genre_id)
+            genre = genre.strip()
+            if genre != '':
+                # Get genre id, add genre if missing
+                genre_id = Lp().genres.get_id(genre)
+                if genre_id is None:
+                    genre_id = Lp().genres.add(genre)
+                    new_genre_ids.append(genre_id)
+                genre_ids.append(genre_id)
         return (genre_ids, new_genre_ids)
 
-    def add_album(self, album_name, artist_id, no_album_artist,
+    def add_album(self, album_name, artist_ids,
                   year, filepath, popularity, mtime):
         """
             Add album to db
             @param album name as string
-            @param album artist id as int
-            @param no album artist as bool
+            @param album artist ids as [int]
             @param path to an album track as string
             @param year as int
             @param popularity as int
@@ -272,30 +319,39 @@ class ScannerTagReader(TagReader):
         """
         path = os.path.dirname(filepath)
         new = False
-        if no_album_artist:
-            album_id = Lp().albums.get_compilation_id(album_name, year)
-        else:
+        if artist_ids:
             album_id = Lp().albums.get_non_compilation_id(album_name,
-                                                          artist_id,
+                                                          artist_ids,
                                                           year)
+        else:
+            album_id = Lp().albums.get_compilation_id(album_name, year)
         if album_id is None:
             new = True
-            album_id = Lp().albums.add(album_name, artist_id, no_album_artist,
+            album_id = Lp().albums.add(album_name, artist_ids,
                                        year, path, popularity, mtime)
         # Now we have our album id, check if path doesn't change
         if Lp().albums.get_path(album_id) != path:
             Lp().albums.set_path(album_id, path)
 
-        # If no album artist, handle album artist id for compilations
-        if no_album_artist:
-            if Lp().albums.is_compilation(album_id):
-                Lp().albums.set_artist_id(album_id,
-                                          Type.COMPILATIONS)
-            else:
-                Lp().albums.set_artist_id(album_id,
-                                          artist_id)
         return (album_id, new)
 
+    def update_album(self, album_id, artist_ids, genre_ids):
+        """
+            Set album artists
+            @param album id as int
+            @param artist ids as [int]
+            @param genre ids as [int]
+            @commit needed
+        """
+        # Set artist ids based on content
+        if not artist_ids:
+            Lp().albums.set_artist_ids(
+                                    album_id,
+                                    Lp().albums.calculate_artist_ids(album_id))
+        # Update album genres
+        for genre_id in genre_ids:
+            Lp().albums.add_genre(album_id, genre_id)
+
     def update_track(self, track_id, artist_ids, genre_ids):
         """
             Set track artists/genres
