@@ -12,6 +12,8 @@
 
 from gi.repository import Gtk, Gio, GLib
 
+from gettext import gettext as _
+
 from lollypop.pop_next import NextPopover
 from lollypop.pop_search import SearchPopover
 from lollypop.pop_albums import AlbumsPopover
@@ -37,6 +39,7 @@ class ToolbarEnd(Gtk.Bin):
         self._next_popover = NextPopover()
         self._search = None
         self._timeout_id = None
+        self._next_was_inhibited = False
         builder = Gtk.Builder()
         builder.add_from_resource('/org/gnome/Lollypop/ToolbarEnd.ui')
         builder.connect_signals(self)
@@ -68,6 +71,9 @@ class ToolbarEnd(Gtk.Bin):
         self._settings_button = builder.get_object('settings-button')
 
         self._list_button = builder.get_object('list-button')
+        self._list_button.set_property('has-tooltip', True)
+        self._list_button.connect('query-tooltip',
+                                  self._on_list_button_query_tooltip)
         list_action = Gio.SimpleAction.new('list', None)
         list_action.connect('activate', self._on_list_button_clicked)
         app.add_action(list_action)
@@ -194,11 +200,13 @@ class ToolbarEnd(Gtk.Bin):
             Show search widget on search button clicked
             @param obj as Gtk.Button or Gtk.Action
         """
+        self._next_was_inhibited = self._next_popover.inhibited
+        self._next_popover.hide()
+        self._next_popover.inhibit(True)
         if self._search is None:
             self._search = SearchPopover()
             self._search.connect('closed', self._on_popover_closed)
         self._search.set_relative_to(self._search_button)
-        self._next_popover.hide()
         self._search.show()
 
     def _on_party_button_toggled(self, button):
@@ -230,7 +238,9 @@ class ToolbarEnd(Gtk.Bin):
         """
         if self._list_popover is not None:
             return
+        self._next_was_inhibited = self._next_popover.inhibited
         self._next_popover.hide()
+        self._next_popover.inhibit(True)
         if Lp().player.current_track.id == Type.EXTERNALS:
             self._list_popover = ExternalsPopover()
             self._list_popover.set_relative_to(self._list_button)
@@ -264,6 +274,8 @@ class ToolbarEnd(Gtk.Bin):
             Restore next popover if needed
             @param popover as Gtk.Popover
         """
+        if not self._next_was_inhibited:
+            self._next_popover.inhibit(False)
         if self._next_popover.should_be_shown():
             self._next_popover.show()
 
@@ -280,3 +292,21 @@ class ToolbarEnd(Gtk.Bin):
             @param widget as Gtk.Widget
         """
         self._next_popover.hide()
+
+    def _on_list_button_query_tooltip(self, widget, x, y, keyboard, tooltip):
+        """
+            Show tooltip
+            @param widget as Gtk.Widget
+            @param x as int
+            @param y as int
+            @param keyboard as bool
+            @param tooltip as Gtk.Tooltip
+        """
+        if Lp().player.current_track.id == Type.EXTERNALS:
+            widget.set_tooltip_text(_("Externals tracks playing"))
+        elif Lp().player.get_queue():
+            widget.set_tooltip_text(_("Queue"))
+        elif Lp().player.get_user_playlist_ids():
+            widget.set_tooltip_text(_("Playing playlists"))
+        else:
+            widget.set_tooltip_text(_("Playing albums"))
