@@ -67,7 +67,7 @@ class PlaylistsWidget(Gtk.Bin):
         """
         return Type.PLAYLISTS
 
-    def update_overlay(self):
+    def set_overlay(self, bool):
         """
             No overlay here now
         """
@@ -308,7 +308,8 @@ class PlaylistsWidget(Gtk.Bin):
             if (src_track.album.artist_id == Type.COMPILATIONS or
                     len(src_track.artist_ids) > 1 or
                     src_track.album.artist_id not in src_track.artist_ids):
-                name = "<b>%s</b>\n%s" % (escape(src_track.artist_names), name)
+                name = "<b>%s</b>\n%s" % (escape(", ".join(src_track.artists)),
+                                          name)
             self._tracks1.insert(index, src_track.id)
         row = PlaylistRow(src_track.id,
                           index,
@@ -328,6 +329,20 @@ class PlaylistsWidget(Gtk.Bin):
             @param src as int
             @param up as bool
         """
+        def update_playlist():
+            # Save playlist in db only if one playlist visible
+            if len(self._playlist_ids) == 1 and self._playlist_ids[0] >= 0:
+                Lp().playlists.clear(self._playlist_ids[0], False)
+                tracks = []
+                for track_id in self._tracks1 + self._tracks2:
+                    tracks.append(Track(track_id))
+                Lp().playlists.add_tracks(self._playlist_ids[0],
+                                          tracks,
+                                          False)
+            if not (set(self._playlist_ids) -
+               set(Lp().player.get_user_playlist_ids())):
+                Lp().player.update_user_playlist(self._tracks1 + self._tracks2)
+
         (src_widget, dst_widget, src_index, dst_index) = \
             self._move_track(dst, src, up)
         self._update_tracks()
@@ -335,19 +350,9 @@ class PlaylistsWidget(Gtk.Bin):
         self._update_headers()
         self._tracks_widget_left.update_indexes(1)
         self._tracks_widget_right.update_indexes(len(self._tracks1) + 1)
-        # Save playlist in db only if one playlist visible
-        if len(self._playlist_ids) == 1 and self._playlist_ids[0] >= 0:
-            Lp().playlists.clear(self._playlist_ids[0], False)
-            tracks = []
-            for track_id in self._tracks1 + self._tracks2:
-                tracks.append(Track(track_id))
-            Lp().playlists.add_tracks(self._playlist_ids[0],
-                                      tracks,
-                                      False)
-        if Lp().player.get_user_playlist_ids() == self._playlist_ids:
-            Lp().player.populate_user_playlist_by_tracks(self._tracks1 +
-                                                         self._tracks2,
-                                                         self._playlist_ids)
+        t = Thread(target=update_playlist)
+        t.daemon = True
+        t.start()
 
     def _on_size_allocate(self, widget, allocation):
         """
@@ -392,15 +397,17 @@ class PlaylistsManagerWidget(Gtk.Bin):
         Widget for playlists management
     """
 
-    def __init__(self, object_id, genre_id, is_album):
+    def __init__(self, object_id, genre_ids, artist_ids, is_album):
         """
             Init widget
             @param object id as int
-            @param genre id as int
+            @param genre ids as [int]
+            @param artist ids as [int]
             @param is album as bool
         """
         Gtk.Bin.__init__(self)
-        self._genre_id = genre_id
+        self._genre_ids = genre_ids
+        self._artist_ids = artist_ids
         self._object_id = object_id
         self._is_album = is_album
         self._deleted_path = None
@@ -513,7 +520,8 @@ class PlaylistsManagerWidget(Gtk.Bin):
                     selected = Lp().playlists.exists_album(
                                                        playlist[0],
                                                        self._object_id,
-                                                       self._genre_id)
+                                                       self._genre_ids,
+                                                       self._artist_ids)
                 else:
 
                     selected = Lp().playlists.exists_track(
@@ -599,7 +607,8 @@ class PlaylistsManagerWidget(Gtk.Bin):
             tracks = []
             if self._is_album:
                 tracks_ids = Lp().albums.get_tracks(self._object_id,
-                                                    self._genre_id)
+                                                    self._genre_ids,
+                                                    self._artist_ids)
                 for track_id in tracks_ids:
                     tracks.append(Track(track_id))
             else:
@@ -721,7 +730,7 @@ class PlaylistEditWidget(Gtk.Bin):
         """
             Append tracks
         """
-        track_ids = Lp().playlists.get_tracks_ids(self._playlist_id)
+        track_ids = Lp().playlists.get_track_ids(self._playlist_id)
         GLib.idle_add(self._append_track, track_ids)
 
     def _append_track(self, track_ids):
@@ -731,13 +740,13 @@ class PlaylistEditWidget(Gtk.Bin):
         """
         if track_ids:
             track = Track(track_ids.pop(0))
-            if track.album.artist_id == Type.COMPILATIONS:
-                artist_name = track.artist_names
+            if track.album.artist_ids[0] == Type.COMPILATIONS:
+                artists = ", ".join(track.artists)
             else:
-                artist_name = track.album.artist_name
+                artists = ", ".join(track.album.artists)
             self._model.append([track.album.id,
                                "<b>%s</b>\n%s" % (
-                                   escape(artist_name),
+                                   escape(artists),
                                    escape(track.name)),
                                 'user-trash-symbolic', track.id])
             GLib.idle_add(self._append_track, track_ids)
@@ -806,9 +815,9 @@ class PlaylistEditWidget(Gtk.Bin):
             tracks.append(track)
             if self._playlist_id == Type.LOVED and Lp().lastfm is not None:
                 if track.album.artist_id == Type.COMPILATIONS:
-                    artist_name = track.artist_names
+                    artist_name = ", ".join(track.artists)
                 else:
-                    artist_name = track.album.artist_name
+                    artist_name = ", ".join(track.album.artists)
                 t = Thread(target=Lp().lastfm.unlove,
                            args=(artist_name, track.name))
                 t.daemon = True
